import {Component, Inject, OnInit} from '@angular/core';
import {FormControl, UntypedFormControl, Validators} from "@angular/forms";
import * as _moment from 'moment';
import {DateAdapter, MAT_DATE_FORMATS, MAT_DATE_LOCALE} from "@angular/material/core";
import {MomentDateAdapter} from "@angular/material-moment-adapter";
import {MAT_DIALOG_DATA, MatDialogRef} from "@angular/material/dialog";
import {TaskService} from "../../../api";
import {TaskEditorData} from "./TaskEditorData";
import {MatSnackBar} from "@angular/material/snack-bar";


@Component({
  selector: 'app-task-editor',
  templateUrl: './task-editor.component.html',
  styleUrls: ['./task-editor.component.css'],
})
export class TaskEditorComponent implements OnInit {

  nameCtrl: FormControl = new FormControl('', [Validators.required, Validators.maxLength(255)])
  etaCtrl: FormControl = new FormControl(0, [Validators.required, Validators.min(0)])
  startDate: FormControl = new FormControl(Date.now(), [Validators.required])
  endDate: FormControl = new FormControl('');
  constructor(private dialog: MatDialogRef<TaskEditorComponent>,
              private taskService: TaskService,
              @Inject(MAT_DIALOG_DATA) public editorData: TaskEditorData,
              private snackbar: MatSnackBar) { }

  ngOnInit(): void {
  }

  cancel() {
    this.dialog.close();
  }

  submit() {
    this.taskService.tasksTaskgroupIDPut(this.editorData.taskgroupID, {
      taskName: this.nameCtrl.value,
      eta: this.etaCtrl.value,
      startDate: this.startDate.value,
      deadline: this.endDate.value
    }).subscribe({
      next: resp => {
        this.dialog.close(resp);
      },
      error: err => {
        if(err.status == 403) {
          this.snackbar.open("No permission", "", {duration: 2000});
        } else if(err.status == 404) {
          this.snackbar.open("Taskgroup not found", "", {duration: 2000});
        } else if(err.status == 409) {
          this.snackbar.open("Task already exists", "", {duration: 2000});
        } else  {
          this.snackbar.open("Unexpected error", "", {duration: 3000});
        }
      }
    })
  }
}
